[jbossws-commits] JBossWS SVN: r3327 - in trunk/jbossws-core/src/test/java/org/jboss/test/ws: jaxrpc/enventry and 1 other directories.

jbossws-commits at lists.jboss.org jbossws-commits at lists.jboss.org
Thu May 31 07:46:47 EDT 2007


Author: thomas.diesler at jboss.com
Date: 2007-05-31 07:46:47 -0400 (Thu, 31 May 2007)
New Revision: 3327

Modified:
   trunk/jbossws-core/src/test/java/org/jboss/test/ws/TestDeployerTomcat.java
   trunk/jbossws-core/src/test/java/org/jboss/test/ws/jaxrpc/enventry/EnvEntryHandler.java
   trunk/jbossws-core/src/test/java/org/jboss/test/ws/jaxws/wsaddressing/AddressingHandler.java
Log:
Fix test regression

Modified: trunk/jbossws-core/src/test/java/org/jboss/test/ws/TestDeployerTomcat.java
===================================================================
--- trunk/jbossws-core/src/test/java/org/jboss/test/ws/TestDeployerTomcat.java	2007-05-31 11:46:12 UTC (rev 3326)
+++ trunk/jbossws-core/src/test/java/org/jboss/test/ws/TestDeployerTomcat.java	2007-05-31 11:46:47 UTC (rev 3327)
@@ -111,7 +111,7 @@
 
    private String getManagerPath() throws MalformedURLException
    {
-      String hostName = System.getProperty("jbosstest.server.host", "localhost");
+      String hostName = System.getProperty("jboss.bind.address", "localhost");
       return "http://" + hostName + ":8080/manager";
    }
 

Modified: trunk/jbossws-core/src/test/java/org/jboss/test/ws/jaxrpc/enventry/EnvEntryHandler.java
===================================================================
--- trunk/jbossws-core/src/test/java/org/jboss/test/ws/jaxrpc/enventry/EnvEntryHandler.java	2007-05-31 11:46:12 UTC (rev 3326)
+++ trunk/jbossws-core/src/test/java/org/jboss/test/ws/jaxrpc/enventry/EnvEntryHandler.java	2007-05-31 11:46:47 UTC (rev 3327)
@@ -97,12 +97,12 @@
    abstract public InitialContext getInitialContext() throws NamingException;
 
    /**
     * Get the JBoss server host from system property "jbosstest.server.host"
     * This defaults to "" + getServerHost() + ""
     */
    public String getServerHost()
    {
-      String hostName = System.getProperty("jbosstest.server.host", "localhost");
+      String hostName = System.getProperty("jboss.bind.address", "localhost");
       return hostName;
    }
 }
@@ -97,12 +97,12 @@
 
    /**
-    * Get the JBoss server host from system property "jbosstest.server.host"
+    * Get the JBoss server host from system property "jboss.bind.address"
     * This defaults to "" + getServerHost() + ""
     */

Modified: trunk/jbossws-core/src/test/java/org/jboss/test/ws/jaxws/wsaddressing/AddressingHandler.java
===================================================================
--- trunk/jbossws-core/src/test/java/org/jboss/test/ws/jaxws/wsaddressing/AddressingHandler.java	2007-05-31 11:46:12 UTC (rev 3326)
+++ trunk/jbossws-core/src/test/java/org/jboss/test/ws/jaxws/wsaddressing/AddressingHandler.java	2007-05-31 11:46:47 UTC (rev 3327)
@@ -32,12 +32,12 @@
 public abstract class AddressingHandler extends GenericHandler
 {
    /**
     * Get the JBoss server host from system property "jbosstest.server.host"
     * This defaults to "" + getServerHost() + ""
     */
    public String getServerHost()
    {
-      String hostName = System.getProperty("jbosstest.server.host", "localhost");
+      String hostName = System.getProperty("jboss.bind.address", "localhost");
       return hostName;
    }
 }
@@ -32,12 +32,12 @@
 {
    /**
-    * Get the JBoss server host from system property "jbosstest.server.host"
+    * Get the JBoss server host from system property "jboss.bind.address"
     * This defaults to "" + getServerHost() + ""
     */




More information about the jbossws-commits mailing list